==> jc-1.4.0.tar.gz: polyglot/lex/NullLiteral.h <==
// public class polyglot.lex.NullLiteral

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class f280b3524c117768 polyglot_lex_NullLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_NullLiteral_H_
#define _JC_polyglot_lex_NullLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_NullLiteral$sub_refs	_jc_polyglot_lex_NullLiteral$sub_refs;
typedef struct _jc_polyglot_lex_NullLiteral$sub_nonrefs	_jc_polyglot_lex_NullLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_NullLiteral$refs	_jc_polyglot_lex_NullLiteral$refs;
typedef struct _jc_polyglot_lex_NullLiteral$nonrefs	_jc_polyglot_lex_NullLiteral$nonrefs;
typedef struct _jc_polyglot_lex_NullLiteral$object	_jc_polyglot_lex_NullLiteral$object;

typedef const struct _jc_polyglot_lex_NullLiteral$vmethods	_jc_polyglot_lex_NullLiteral$vmethods;
typedef const struct _jc_polyglot_lex_NullLiteral$vtable	_jc_polyglot_lex_NullLiteral$vtable;
typedef const struct _jc_polyglot_lex_NullLiteral$vtype	_jc_polyglot_lex_NullLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_NullLiteral$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_NullLiteral$object *, struct _jc_polyglot_util_Position$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_NullLiteral$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_NullLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_NullLiteral$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_NullLiteral$object *);
};

// Vtable
struct _jc_polyglot_lex_NullLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NullLiteral$vmethods	polyglot_lex_NullLiteral;
};

// Vtype
struct _jc_polyglot_lex_NullLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_NullLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_NullLiteral$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_NullLiteral$refs {
    _jc_polyglot_lex_NullLiteral$sub_refs	polyglot_lex_NullLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_NullLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_NullLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NullLiteral$sub_nonrefs	polyglot_lex_NullLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_NullLiteral$object {
	_jc_polyglot_lex_NullLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_NullLiteral$vtype	*vtype;
	_jc_polyglot_lex_NullLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_NullLiteral$vtype _jc_polyglot_lex_NullLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_NullLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_NullLiteral$class_object;

#endif	/* _JC_polyglot_lex_NullLiteral_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/NullLiteral.h <==
// public class polyglot.lex.NullLiteral

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class f280b3524c117768 polyglot_lex_NullLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_NullLiteral_H_
#define _JC_polyglot_lex_NullLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_NullLiteral$sub_refs	_jc_polyglot_lex_NullLiteral$sub_refs;
typedef struct _jc_polyglot_lex_NullLiteral$sub_nonrefs	_jc_polyglot_lex_NullLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_NullLiteral$refs	_jc_polyglot_lex_NullLiteral$refs;
typedef struct _jc_polyglot_lex_NullLiteral$nonrefs	_jc_polyglot_lex_NullLiteral$nonrefs;
typedef struct _jc_polyglot_lex_NullLiteral$object	_jc_polyglot_lex_NullLiteral$object;

typedef const struct _jc_polyglot_lex_NullLiteral$vmethods	_jc_polyglot_lex_NullLiteral$vmethods;
typedef const struct _jc_polyglot_lex_NullLiteral$vtable	_jc_polyglot_lex_NullLiteral$vtable;
typedef const struct _jc_polyglot_lex_NullLiteral$vtype	_jc_polyglot_lex_NullLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_NullLiteral$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_NullLiteral$object *, struct _jc_polyglot_util_Position$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_NullLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_NullLiteral$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_NullLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_NullLiteral$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_NullLiteral$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_NullLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NullLiteral$vmethods	polyglot_lex_NullLiteral;
};

// Vtype
struct _jc_polyglot_lex_NullLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_NullLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_NullLiteral$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_NullLiteral$refs {
    _jc_polyglot_lex_NullLiteral$sub_refs	polyglot_lex_NullLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_NullLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_NullLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NullLiteral$sub_nonrefs	polyglot_lex_NullLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_NullLiteral$object {
	_jc_polyglot_lex_NullLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_NullLiteral$vtype	*vtype;
	_jc_polyglot_lex_NullLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_NullLiteral$vtype _jc_polyglot_lex_NullLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_NullLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_NullLiteral$class_object;

#endif	/* _JC_polyglot_lex_NullLiteral_H_ */
